@@ -4,6 +4,7 @@ use crate::{
         optimize::Ctx,
         util::{always_terminates, negate_cost},
     },
+    mode::Mode,
     util::SpanExt,
     DISABLE_BUGGY_PASSES,
 };
@@ -15,7 +16,10 @@ use swc_ecma_utils::{ident::IdentLike, ExprExt, ExprFactory, StmtLike};
 
 /// Methods related to the option `conditionals`. All methods are noop if
 /// `conditionals` is false.
-impl Optimizer<'_> {
+impl<M> Optimizer<'_, M>
+where
+    M: Mode,
+{
     /// Negates the condition of a `if` statement to reduce body size.
     pub(super) fn negate_if_stmt(&mut self, stmt: &mut IfStmt) {
         let alt = match stmt.alt.as_deref_mut() {
