@@ -1,5 +1,5 @@
 use super::Optimizer;
-use crate::{compress::util::eval_as_number, DISABLE_BUGGY_PASSES};
+use crate::{compress::util::eval_as_number, mode::Mode, DISABLE_BUGGY_PASSES};
 use std::num::FpCategory;
 use swc_atoms::js_word;
 use swc_common::{Spanned, SyntaxContext, DUMMY_SP};
@@ -8,7 +8,10 @@ use swc_ecma_transforms_base::ext::MapWithMut;
 use swc_ecma_utils::{ident::IdentLike, undefined, ExprExt, Value::Known};
 
 /// Methods related to the option `evaludate`.
-impl Optimizer<'_> {
+impl<M> Optimizer<'_, M>
+where
+    M: Mode,
+{
     /// Evaludate expression if possible.
     ///
     /// This method call apppropriate methods for each ast types.
