@@ -1,6 +1,7 @@
 use super::Pure;
 use crate::{
     compress::util::{is_pure_undefined, negate, negate_cost},
+    mode::Mode,
     util::make_bool,
 };
 use std::mem::swap;
@@ -10,7 +11,10 @@ use swc_ecma_ast::*;
 use swc_ecma_transforms_base::ext::MapWithMut;
 use swc_ecma_utils::{ExprExt, Type, Value};
 
-impl Pure<'_> {
+impl<M> Pure<'_, M>
+where
+    M: Mode,
+{
     pub(super) fn negate_twice(&mut self, e: &mut Expr) {
         self.changed = true;
         negate(e, false);
