@@ -1,12 +1,15 @@
 use super::Pure;
-use crate::{compress::util::negate_cost, debug::dump, util::make_bool};
+use crate::{compress::util::negate_cost, debug::dump, mode::Mode, util::make_bool};
 use std::mem::swap;
 use swc_common::{EqIgnoreSpan, Spanned};
 use swc_ecma_ast::*;
 use swc_ecma_transforms_base::ext::MapWithMut;
 use swc_ecma_utils::{ExprExt, Type, Value};
 
-impl Pure<'_> {
+impl<M> Pure<'_, M>
+where
+    M: Mode,
+{
     ///
     /// - `foo ? bar : false` => `!!foo && bar`
     /// - `!foo ? true : bar` => `!foo || bar`
