@@ -1,5 +1,5 @@
 use super::Pure;
-use crate::compress::util::always_terminates;
+use crate::{compress::util::always_terminates, mode::Mode};
 use swc_atoms::js_word;
 use swc_common::DUMMY_SP;
 use swc_ecma_ast::*;
@@ -7,7 +7,10 @@ use swc_ecma_transforms_base::ext::MapWithMut;
 use swc_ecma_utils::{ExprExt, StmtLike, Value};
 
 /// Methods related to option `dead_code`.
-impl Pure<'_> {
+impl<M> Pure<'_, M>
+where
+    M: Mode,
+{
     pub(super) fn drop_useless_blocks<T>(&mut self, stmts: &mut Vec<T>)
     where
         T: StmtLike,
