@@ -1,12 +1,14 @@
-use crate::compress::util::get_lhs_ident;
-
 use super::Pure;
+use crate::{compress::util::get_lhs_ident, mode::Mode};
 use swc_common::{SyntaxContext, DUMMY_SP};
 use swc_ecma_ast::*;
 use swc_ecma_transforms_base::ext::MapWithMut;
 use swc_ecma_utils::{ExprExt, ExprFactory};
 
-impl Pure<'_> {
+impl<M> Pure<'_, M>
+where
+    M: Mode,
+{
     pub(super) fn drop_useless_ident_ref_in_seq(&mut self, seq: &mut SeqExpr) {
         if !self.options.collapse_vars {
             return;
