@@ -1,3 +1,5 @@
+use super::Pure;
+use crate::mode::Mode;
 use swc_common::DUMMY_SP;
 use swc_ecma_ast::*;
 use swc_ecma_transforms_base::ext::MapWithMut;
@@ -6,9 +8,10 @@ use swc_ecma_visit::{
     noop_visit_mut_type, noop_visit_type, Node, Visit, VisitMut, VisitMutWith, VisitWith,
 };
 
-use super::Pure;
-
-impl Pure<'_> {
+impl<M> Pure<'_, M>
+where
+    M: Mode,
+{
     /// Collapse single-use non-constant variables, side effects permitting.
     ///
     /// This merges all variables to first variable declartion with an
